==> haskell-lattices-2.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2
visibility:           public
id:                   lattices-2.2-6WZYew3WWto7GuLx6D4klq
key:                  lattices-2.2-6WZYew3WWto7GuLx6D4klq
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  0e7bbe8b56e2080ff0b4e3ed6ecab42b
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2-6WZYew3WWto7GuLx6D4klq
depends:
    QuickCheck-2.14.3-1JAfsK5YqEi18geygBPUiU base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 containers-0.6.7
    deepseq-1.4.8.0 foldable1-classes-compat-0.1-D8NL8QUvnWxKNZ1Fh1aJmU
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    integer-logarithms-1.0.3.1-JfoQIJXh5PhDnmGGlkJE4T
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-GkeDDolcNlF9mSawYhf8Yh
    universe-reverse-instances-1.1.2-GjBK7e9c6gE2rTJUNctYFI
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lattices-2.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2
visibility:           public
id:                   lattices-2.2-EAMWijKgJrs3ajQGNlTsHu
key:                  lattices-2.2-EAMWijKgJrs3ajQGNlTsHu
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  4a163f5d68c9cf9cc6cc2ce91e9ba4c9
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2-EAMWijKgJrs3ajQGNlTsHu
depends:
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 containers-0.6.7
    deepseq-1.4.8.0 foldable1-classes-compat-0.1-KNC71VpGsYyJp02CjvY29Z
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    integer-logarithms-1.0.3.1-JfoQIJXh5PhDnmGGlkJE4T
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-4VWe2RTMCeQFS8muxpQiPB
    universe-reverse-instances-1.1.2-JMnGfU1dcYl6gMRhPQTo2l
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
